CoverageLine class
Coverage details for a single source line.
Constructors
- CoverageLine({required int number, required int hitCount, required CoverageLineStatus status, required String text, int branchFound = 0, int branchHit = 0})
-
Creates an annotated source line.
const
Properties
- branchFound → int
-
Number of branch outcomes mapped to this line.
final
- branchHit → int
-
Number of branch outcomes on this line that executed at least once.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitCount → int
-
LCOV execution count for this line.
final
- number → int
-
One-based source line number.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CoverageLineStatus
-
Display status derived from LCOV and ignore directives.
final
- text → String
-
Source text for this line, or an empty string when missing.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited